﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfApplication3
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();
		}
	}

	/// <summary>
	/// Class to serve as base class for MVVM View Models in WPF
	/// </summary>
	public class ViewModelBase : INotifyPropertyChanged
	{
		/// <summary>
		/// Public event to fire when a property changes
		/// </summary>
		public event PropertyChangedEventHandler PropertyChanged = null;

		/// <summary>
		/// Raises a property changed event
		/// </summary>
		/// <param name="property">The name of the property.  If not specified, it will take the name of the property it is called from</param>
		public void RaisePropertyChanged([CallerMemberName] String property = null)
		{
			this.PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(property));
		}
	}

	public class ItemsViewModel : ViewModelBase
	{
		public ItemsViewModel()
		{
			Items = new ObservableCollection<ItemViewModel>();

			Items.Add(new ItemViewModel() {ItemName = "Item 1"});
			Items.Add(new ItemViewModel() {ItemName = "Item 2"});
			Items.Add(new ItemViewModel() {ItemName = "Item 3"});
			Items.Add(new ItemViewModel() {ItemName = "Item 4"});
			Items.Add(new ItemViewModel() {ItemName = "Item 5"});
			Items.Add(new ItemViewModel() {ItemName = "Item 6"});
			Items.Add(new ItemViewModel() {ItemName = "Item 7" });
		}

		private ObservableCollection<ItemViewModel> _items;

		public ObservableCollection<ItemViewModel> Items {
			get { return _items; }
			set
			{
				_items = value;
				this.RaisePropertyChanged();
			}
		}
	}

	public class ItemViewModel : ViewModelBase
	{
		public ItemViewModel()
		{
			ItemIcon = new BitmapImage(new Uri("/l.png", UriKind.Relative));
		}

		private string _itemName;
		public string ItemName { get { return _itemName; } set { _itemName = value; this.RaisePropertyChanged();} }

		private BitmapImage _itemIcon;
		public BitmapImage ItemIcon { get { return _itemIcon; } set { _itemIcon = value; this.RaisePropertyChanged();} }
	}
}
